/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.core;

import com.vektorsoft.demux.core.common.PropertBindingController;
import com.vektorsoft.demux.core.common.ViewActivationController;
import com.vektorsoft.demux.core.mva.DMXAdapter;
import org.osgi.framework.BundleContext;
import org.osgi.framework.ServiceReference;
import org.osgi.util.tracker.ServiceTrackerCustomizer;

/**
 * Customizer for {@link DMXAdapter} service. It will handle registration of common controllers 
 * and view which can be reused across platforms.
 *
 * @author Vladimir Djurovic
 */
public class DemuxCoreCustomizer implements ServiceTrackerCustomizer<DMXAdapter, DMXAdapter> {
    
    /** Bundle context. */
    private final BundleContext context;
    
    /** Creates new instance. 
     * 
     * @param ctx bundle context
     */
    public DemuxCoreCustomizer(BundleContext ctx){
        this.context = ctx;
    }

    @Override
    public DMXAdapter addingService(ServiceReference<DMXAdapter> sr) {
        DMXAdapter svc = (DMXAdapter)context.getService(sr);
        
        // register views and controllers here
       svc.registerController(new ViewActivationController());
       svc.registerController(new PropertBindingController());
        
       return svc;
    }

    @Override
    public void modifiedService(ServiceReference<DMXAdapter> sr, DMXAdapter t) {
        
    }

    @Override
    public void removedService(ServiceReference<DMXAdapter> sr, DMXAdapter t) {
        
    }

}
