/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/


package com.vektorsoft.demux.core.extension;

import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Properties;

/**
 * Default implementation of {@link DMXExtensionConfig} interface. This class simply provides empty
 * callbacks list and configuration properties. Also, it provides hooks for subclasses where custom 
 * properties can be added.
 *
 * @author Vladimir Djurovic
 */
public class DefaultExtensionConfig implements DMXExtensionConfig {
    
    /**
     * List of extension callbacks.
     */
    protected List<DMXExtensionCallback> callbacks;
    
    /**
     * Configuration properties.
     */
    protected Properties configProperties;
    
    /**
     * Creates new instance.
     */
    public DefaultExtensionConfig(){
        callbacks = new ArrayList<DMXExtensionCallback>();
        configProperties = new Properties();
    }
    
    /**
     * Returns an array of extension callbacks defined in subclass. This method is 
     * intended to be overriden by subclasses to return custom callbacks array.
     * 
     * @return array of extension callbacks
     */
    protected DMXExtensionCallback[] getCustomCallbacks(){
        return new DMXExtensionCallback[0];
    }
    
    /**
     * Returns custom configuration properties. By default, this method returns empty
     * properties. It is intended to be overriden by subclasses to return custom properties.
     * 
     * @return configuration properties
     */
    protected Properties getCustomProperties(){
        return new Properties();
    }

    @Override
    public final List<DMXExtensionCallback> getExtensionCallbacks() {
        callbacks.addAll(Arrays.asList(getCustomCallbacks()));
        return callbacks;
    }

    @Override
    public final Properties getActivatorConfig() {
        configProperties.putAll(getCustomProperties());
        return configProperties;
    }

}
