/******************************************************************************
 * 
 * Copyright 2012 - 2014 Vektor Software.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * 
 *****************************************************************************/

package com.vektorsoft.demux.core.mva;

/**
 * <p>
 *  Defines common way to register event listeners for UI components on supported platforms. Event 
 * listeners are registered on UI components whose IDs are returned from {@code #getComponentIds() }
 * method. Implementations of this interface should then take care of finding those components and 
 * registering listeners on them. Listeners handle type of events declared with parameter {@code T}.
 * </p>
 *
 * @param <T> event handler for the events
 * @author Vladimir Djurovic
 */
public interface DMXEventRegistrationHandler<T> {

    /**
     * Returns IDs of UI components on which event listeners will be registered.
     * 
     * @return component IDs
     */
    String[] getComponentIds();
    
    /**
     * Event handler for the events.
     * 
     * @return event handler
     */
    T getEventHandler();
}
